This is to maintain the files related BlackDuck library.

The user will execute blackduck.py with all the required arguments. The blackduck.py will internally call blackducklib.py

The test_blackduck.py file is used to add the unit test.